@@ -2,14 +2,12 @@ from __future__ import annotations
 
 import os
 import sys
-from datetime import datetime
+from datetime import datetime, timezone
 from pathlib import Path
 from subprocess import CalledProcessError
-from typing import Callable
-from unittest.mock import MagicMock
+from typing import TYPE_CHECKING, Callable
 
 import pytest
-from pytest_mock import MockerFixture
 
 from virtualenv.app_data import AppDataDiskFolder
 from virtualenv.seed.wheels.acquire import download_wheel, get_wheel, pip_wheel_env_run
@@ -17,6 +15,11 @@ from virtualenv.seed.wheels.embed import BUNDLE_FOLDER, get_embed_wheel
 from virtualenv.seed.wheels.periodic_update import dump_datetime
 from virtualenv.seed.wheels.util import Wheel, discover_wheels
 
+if TYPE_CHECKING:
+    from unittest.mock import MagicMock
+
+    from pytest_mock import MockerFixture
+
 
 @pytest.fixture(autouse=True)
 def _fake_release_date(mocker):
@@ -62,7 +65,7 @@ def test_download_fails(mocker, for_py_version, session_app_data):
 
     as_path = mocker.MagicMock()
     with pytest.raises(CalledProcessError) as context:
-        download_wheel("pip", "==1", for_py_version, [], session_app_data, as_path, os.environ),
+        download_wheel("pip", "==1", for_py_version, [], session_app_data, as_path, os.environ)
     exc = context.value
     assert exc.output == "out"
     assert exc.stderr == "err"
@@ -123,7 +126,7 @@ def test_get_wheel_download_cached(
     downloaded_wheel: tuple[Wheel, MagicMock],
     time_freeze: Callable[[datetime], None],
 ) -> None:
-    time_freeze(datetime.now())
+    time_freeze(datetime.now(tz=timezone.utc))
     from virtualenv.app_data.via_disk_folder import JSONStoreDisk
 
     app_data = AppDataDiskFolder(folder=str(tmp_path))
@@ -150,7 +153,7 @@ def test_get_wheel_download_cached(
             {
                 "filename": expected.name,
                 "release_date": None,
-                "found_date": dump_datetime(datetime.now()),
+                "found_date": dump_datetime(datetime.now(tz=timezone.utc)),
                 "source": "download",
             },
         ],
